summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-01-01 18:27:30 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2010-01-01 18:29:51 -0600
commit5cfea4fc9813fe675f02d2f5cae7c60ee2e5163c (patch)
tree9013368934e1c2c6ed2e721054372191113e7130 /png.h
parenta87c870f991a877458edd19056b8ca2e7dcc994d (diff)
downloadlibpng-5cfea4fc9813fe675f02d2f5cae7c60ee2e5163c.tar.gz
[master] Imported from libpng-1.2.42rc05.tarv1.2.42rc05
Diffstat (limited to 'png.h')
-rw-r--r--png.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/png.h b/png.h
index 3dc56b14e..834401f73 100644
--- a/png.h
+++ b/png.h
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.42rc04 - January 1, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -10,7 +10,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.42rc04 - January 1, 2010: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -251,7 +251,7 @@
* 1.0.51 10 10051 10.so.0.51[.0]
* 1.2.41 13 10241 12.so.0.41[.0]
* 1.2.42beta01-02 13 10242 12.so.0.42[.0]
- * 1.2.42rc01-04 13 10242 12.so.0.42[.0]
+ * 1.2.42rc01-05 13 10242 12.so.0.42[.0]
* 1.0.52 10 10052 10.so.0.52[.0]
* 1.2.42 13 10242 12.so.0.42[.0]
*
@@ -285,7 +285,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.2.42rc04, January 1, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -397,13 +397,13 @@
* Y2K compliance in libpng:
* =========================
*
- * January 1, 2010
+ * January 2, 2010
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.42rc04 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -459,9 +459,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.42rc04"
+#define PNG_LIBPNG_VER_STRING "1.2.42rc05"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.42rc04 - January 1, 2010\n"
+ " libpng version 1.2.42rc05 - January 2, 2010\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -474,7 +474,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 04
+#define PNG_LIBPNG_VER_BUILD 05
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1530,7 +1530,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_42rc04;
+typedef png_structp version_1_2_42rc05;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,6 +1,6 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.42rc04 - January 1, 2010
+ * libpng version 1.2.42rc05 - January 2, 2010
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -10,7 +10,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.42rc04 - January 1, 2010: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.42rc05 - January 2, 2010: Glenn
* See also "Contributing Authors", below.
*
@@ -285,7 +285,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.2.42rc04, January 1, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.42rc05, January 2, 2010, are
* Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -397,13 +397,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.42rc04 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.42rc05 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*